Querying for Timeline segments
==============================

.. automodule:: gwosc.timeline

.. rubric:: Functions
   :class: h2

.. automodsumm:: gwosc.timeline
   :toctree: reference/
   :skip: itemgetter
